
C      read_next_step_eachpage.f      20 Oct 2014
C       readlastpagenexttraj.f           5/30/96

C  Because of confusion about what is to signal end of traj,
C  or end of file, I am writing this new routine, and there
C  are now permanent changes in WRFT08.  Previously, ie,
C  before 17 Oct 2014, no end-of-traj indicator was written
C  to eachpage files.  The subroutine readlastpagenexttraj
C  would supply a -1 in IYD to signal end-of-file.  If there
C  were multiple trajs on one eachpage file, there was no
C  indication where one stopped and another began.
C  Now this version has ISTATUS in the call statement,
C  ISTATUS=1 -->  a regular trajectory step
C  ISTATUS=0 -->  an error occurred during the read
C  ISTATUS=-1 -->  end of this trajectory
C  ISTATUS=-2 -->  end of file has been reached
C  When ISTATUS=-1 it may still be considered a trajectory step;
C    I'm not sure whether it might be a duplicate of the previous step.
C  The status indication from WRFT08 comes from HOUSE(1),
C  not directly from IYD.
C  Note that ISTATUS=-1 could in fact be the last traj on the
C  file, but we won't have the EOF indication until we try to
C  read beyond it.

C  Actually I've decided to have IUNIT as an input in the call statement.
C  Unit 31 must already be open. [(see above)Returns IYD=-1 if EOF.]

C  New version, includes all 50 HOUSE elements.


C  1- NO+   2- O2+   3- O+   4- [N2]  5- [O2]   6- [O]
C  7- Tn    8- Ti    9- Te   10- Ne

C  All densities are log10.


      SUBROUTINE READ_NEXT_STEP_EACHPAGE(IUNIT,ALTS,PROFS,ISTATUS)
      DIMENSION ALTS(37),PROFS(10,37)
      COMMON/LASTPAGE/IITRAJ,IYD,UTSEC,DLAT,DLON,AP,RKP,     !  DLON deg
     +                F10,F10A,GLOW,XNMF2,XHMF2
      COMMON/LASTPAGEHOUSE/HOUSE(50)
      COMMON/LASTPAGE_A_P/ALTS_2(37),PROFS_2(10,37)
      CHARACTER*80 LYNE
C  File should already be positioned to read this one:
      READ(IUNIT,*,END=800,ERR=888) IITRAJ,IYD,UTSEC,DLAT,DLON,AP,RKP,
     +           F10,F10A,GLOW,XNMF2,XHMF2
      READ(IUNIT,*,ERR=888) HOUSE
      DO K=1,37
       READ(IUNIT,*,END=800,ERR=888) ALTS(K),(PROFS(L,K),L=1,9)
      END DO
      DO K=1,37
       X1=10.0**PROFS(1,K)
       X2=10.0**PROFS(2,K)
       X3=10.0**PROFS(3,K)
       PROFS(10,K)=ALOG10(X1+X2+X3)
      END DO
      DO K=1,37
       ALTS_2(K)=ALTS(K)
       DO L=1,10
         PROFS_2(L,K)=PROFS(L,K)
       END DO
      END DO
      IF(HOUSE(1).GT.0.) THEN
       ISTATUS=1
      ELSE IF(HOUSE(1).LT.0.) THEN
       ISTATUS=-1
      END IF
      RETURN
C  Check to see if HOUSE(1) is a five digit integer, to check version.
C  Note, 17 Oct 2014, looks like this section of code will never be hit.
      IF(AMOD(HOUSE(1),1.0).NE.0. .OR. HOUSE(1).GT.22222 .OR.
     +   HOUSE(1).LT.9999) THEN
       WRITE(0,*) 'Check version of READLASTPAGE, IYD = ',HOUSE(1)
      END IF
800   CONTINUE      !  Here if end-of-file :
      IYD=-1    !  I guess I'll leave this in here, although EOF should
                !  be indicated by HOUSE(1)..
      ISTATUS=-2
      RETURN
888   CONTINUE
      ISTATUS=0
      WRITE(*,*) ' Error in READ_NEXT_STEP_EACHPAGE'
         write(*,*) ' iunit = ',iunit
      BACKSPACE(UNIT=IUNIT)
      READ(IUNIT,7) LYNE
7     FORMAT(A)
      WRITE(*,*) '   At or near this line :'
      WRITE(*,*) LYNE
      STOP
      END






